@@ -57,9 +57,6 @@ class MainWindow( object ):
         builder = Gtk.Builder()
         builder.add_from_file(os.path.join( self.path, "mintMenu.glade" ))
         self.window     = builder.get_object( "mainWindow" )
-        self.window.realize()
-        self.window.get_window().set_decorations(Gdk.WMDecoration.BORDER)
-        self.window.set_title("")
         self.paneholder = builder.get_object( "paneholder" )
 
         builder.connect_signals(self)
@@ -656,20 +653,23 @@ class MenuWin( object ):
             self.button_icon.hide()
         else:
             self.button_icon.show()
-     #   This code calculates width and height for the button_box
-     #   and takes the orientation in account
-        bi_req = self.button_icon.size_request()
-        sl_req = self.systemlabel.size_request()
+
+        # This code calculates width and height for the button_box
+        # and takes the orientation and scale factor in account
+        bi_req = self.button_icon.get_preferred_size()[1]
+        bi_scale = self.button_icon.get_scale_factor()
+        sl_req = self.systemlabel.get_preferred_size()[1]
+        sl_scale = self.systemlabel.get_scale_factor()
         if self.applet.get_orient() == MatePanelApplet.AppletOrient.UP or self.applet.get_orient() == MatePanelApplet.AppletOrient.DOWN:
             if self.hideIcon:
-                self.applet.set_size_request( sl_req.width + 2, bi_req.height )
+                self.applet.set_size_request( sl_req.width / sl_scale + 2, bi_req.height )
             else:
-                self.applet.set_size_request( sl_req.width + bi_req.width + 5, bi_req.height )
+                self.applet.set_size_request( sl_req.width / sl_scale + bi_req.width / bi_scale + 5, bi_req.height )
         else:
             if self.hideIcon:
-                self.applet.set_size_request( bi_req.width, sl_req.height + 2 )
+                self.applet.set_size_request( bi_req.width, sl_req.height / sl_scale + 2 )
             else:
-                self.applet.set_size_request( bi_req.width, sl_req.height + bi_req.height + 5 )
+                self.applet.set_size_request( bi_req.width, sl_req.height / sl_scale + bi_req.height / bi_scale + 5 )
 
     def reloadSettings( self, *args ):
         self.loadSettings()
@@ -746,36 +746,56 @@ class MenuWin( object ):
         entryWidth, entryHeight =  self.applet.get_allocation().width, self.applet.get_allocation().height
         entryHeight = entryHeight + self.mainwin.offset
 
-        # Get the screen dimensions
-        screenHeight = Gdk.Screen.height()
-        screenWidth = Gdk.Screen.width()
-        if self.applet.get_orient() == MatePanelApplet.AppletOrient.UP or self.applet.get_orient() == MatePanelApplet.AppletOrient.DOWN:
-            if entryX + ourWidth < screenWidth or  entryX + entryWidth / 2 < screenWidth / 2:
-                # Align to the left of the entry
-                newX = entryX
-            else:
-                # Align to the right of the entry
-                newX = entryX + entryWidth - ourWidth
-
-            if entryY + entryHeight / 2 < screenHeight / 2:
-                # Align to the bottom of the entry
-                newY = entryY + entryHeight
-            else:
-                newY = entryY - ourHeight
+        # Get the monitor dimensions
+        display = self.applet.get_display()
+        if (Gtk.MAJOR_VERSION, Gtk.MINOR_VERSION) >= (3, 22):
+            monitor = display.get_monitor_at_window(self.applet.get_window())
+            monitorGeometry = monitor.get_geometry()
         else:
-            if entryX + entryWidth / 2 < screenWidth / 2:
-                # Align to the left of the entry
-                newX = entryX + entryWidth
-            else:
-                # Align to the right of the entry
-                newX = entryX - ourWidth
+            screen = display.get_default_screen()
+            monitor = screen.get_monitor_at_window(self.applet.get_window())
+            monitorGeometry = screen.get_monitor_geometry(monitor)
 
-            if entryY + ourHeight < screenHeight or entryY + entryHeight / 2 < screenHeight / 2:
-                # Align to the bottom of the entry
-                newY = entryY
-            else:
-                newY = entryY - ourHeight + entryHeight
-        # -"Move window"
+        applet_orient = self.applet.get_orient()
+        if applet_orient == MatePanelApplet.AppletOrient.UP:
+            newX = entryX
+            newY = entryY - ourHeight
+        elif applet_orient == MatePanelApplet.AppletOrient.DOWN:
+            newX = entryX
+            newY = entryY + entryHeight
+        elif applet_orient == MatePanelApplet.AppletOrient.RIGHT:
+            newX = entryX + entryWidth
+            newY = entryY
+        elif applet_orient == MatePanelApplet.AppletOrient.LEFT:
+            newX = entryX - ourWidth
+            newY = entryY
+
+        # Adjust for offset if we reach the end of the screen
+        # Bind to the right side
+        if newX + ourWidth > (monitorGeometry.x + monitorGeometry.width):
+            newX = (monitorGeometry.x + monitorGeometry.width) - ourWidth
+            if applet_orient == MatePanelApplet.AppletOrient.LEFT:
+                newX -= entryWidth
+
+        # Bind to the left side
+        if newX < monitorGeometry.x:
+            newX = monitorGeometry.x
+            if applet_orient == MatePanelApplet.AppletOrient.RIGHT:
+                newX -= entryWidth;
+
+        # Bind to the bottom
+        if newY + ourHeight > (monitorGeometry.y + monitorGeometry.height):
+            newY = (monitorGeometry.y + monitorGeometry.height) - ourHeight
+            if applet_orient == MatePanelApplet.AppletOrient.UP:
+                newY -= entryHeight
+
+        # Bind to the top
+        if newY < monitorGeometry.y:
+            newY = monitorGeometry.y
+            if applet_orient == MatePanelApplet.AppletOrient.DOWN:
+                newY -= entryHeight
+
+        # Move window
         self.mainwin.window.move( newX, newY )
 
     # this callback is to create a context menu
