@@ -1,13 +1,11 @@
 #!/usr/bin/python2
 
-from gi.repository import Gtk, Gio
+from gi.repository import Gtk, Gio, GLib
 import os
 import string
 import gettext
 import commands
 import time
-import ctypes
-from ctypes import *
 
 from easybuttons import *
 from easygsettings import EasyGSettings
@@ -15,8 +13,6 @@ from execute import Execute
 from user import home
 from urllib import unquote
 
-gtk = CDLL("libgtk-x11-2.0.so.0")
-
 # i18n
 gettext.install("mintmenu", "/usr/share/linuxmint/locale")
 
@@ -223,10 +219,13 @@ class pluginclass( object ):
 
     def do_gtk_bookmarks( self ):
         if self.showGTKBookmarks:
-            if not os.path.exists(os.path.expanduser('~/.gtk-bookmarks')):
+            bookmarksFile = os.path.join(GLib.get_user_config_dir(), "gtk-3.0", "bookmarks")
+            if not os.path.exists(bookmarksFile):
+                bookmarksFile = os.path.join(GLib.get_home_dir(), ".gtk-bookmarks")
+            if not os.path.exists(bookmarksFile):
                 return
             bookmarks = []
-            with open(os.path.expanduser('~/.gtk-bookmarks'), 'r') as f:
+            with open(bookmarksFile, "r") as f:
                 for line in f:
                     #line = line.replace('file://', '')
                     line = line.rstrip()
@@ -263,8 +262,8 @@ class pluginclass( object ):
             trashMenu.show_all()
             emptyTrashMenuItem.connect ( "activate", self.emptyTrash, widget )
             self.mintMenuWin.stopHiding()
-            gtk.gtk_menu_popup.argtypes = [c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_uint, c_uint]
-            gtk.gtk_menu_popup(hash(trashMenu), None, None, None, None, 3, 0)
+            trashMenu.attach_to_widget(widget, None)
+            trashMenu.popup(None, None, None, None, 3, 0)
 
     def emptyTrash( self, menu, widget):
         os.system("rm -rf " + home + "/.local/share/Trash/info/*")
